@@ -1,7 +1,7 @@
 # Functions to manipulate Python binary distribution archives.
 #
 # Author: Peter Odding <peter.odding@paylogic.eu>
-# Last Change: March 20, 2014
+# Last Change: May 15, 2014
 # URL: https://github.com/paylogic/pip-accel
 
 """
@@ -67,10 +67,14 @@ def get_binary_dist(package, version, directory, url=None, python='/usr/bin/pyth
             sanity_check_dependencies(package)
             raw_file = build_binary_dist(package, version, directory, python=python)
         # Transform the binary distribution archive into a form that we can re-use.
-        archive = tarfile.open(cache_file, 'w:gz')
+        transformed_file = '%s.tmp-%i' % (cache_file, os.getpid())
+        archive = tarfile.open(transformed_file, 'w:gz')
         for member, from_handle in transform_binary_dist(raw_file, prefix=prefix):
             archive.addfile(member, from_handle)
         archive.close()
+        # Try to avoid race conditions between multiple processes by atomically
+        # moving the transformed binary distribution into its final place.
+        os.rename(transformed_file, cache_file)
         logger.debug("%s (%s) cached as %s.", package, version, cache_file)
     archive = tarfile.open(cache_file, 'r:gz')
     for member in archive.getmembers():
@@ -97,7 +101,7 @@ def build_binary_dist(package, version, directory, python='/usr/bin/python'):
     setup_script = os.path.join(directory, 'setup.py')
     if not os.path.isfile(setup_script):
         msg = "Directory %s (%s %s) doesn't contain a source distribution!"
-        raise InvalidSourceDistribution, msg % (directory, package, version)
+        raise InvalidSourceDistribution(msg % (directory, package, version))
     # Let the user know what's going on.
     build_text = "Building binary distribution of %s (%s) .." % (package, version)
     logger.info("%s", build_text)
@@ -128,12 +132,12 @@ def build_binary_dist(package, version, directory, python='/usr/bin/python'):
             logger.error("%s", msg)
             with open(temporary_file) as handle:
                 logger.info("Build output (will probably provide a hint as to what went wrong):\n%s", handle.read())
-            raise BuildFailed, msg
+            raise BuildFailed(msg)
         # Check if we can find the binary distribution archive.
         filenames = os.listdir(dist_directory)
         if len(filenames) != 1:
             msg = "Build process did not result in one binary distribution! (matches: %s)"
-            raise NoBuildOutput, msg % filenames
+            raise NoBuildOutput(msg % filenames)
         logger.info("Finished building %s (%s) in %s.", package, version, build_timer)
         return os.path.join(dist_directory, filenames[0])
     finally:
@@ -219,9 +223,9 @@ def install_binary_dist(members, prefix, python='/usr/bin/python', enable_workar
             logger.debug("Creating directory: %s ..", directory)
             os.makedirs(directory)
         logger.debug("Creating file: %s ..", pathname)
-        with open(pathname, 'w') as to_handle:
+        with open(pathname, 'wb') as to_handle:
             contents = from_handle.read()
-            if contents.startswith('#!/'):
+            if contents.startswith(b'#!/'):
                 contents = fix_hashbang(python, contents)
             to_handle.write(contents)
         os.chmod(pathname, member.mode)
@@ -240,16 +244,16 @@ def fix_hashbang(python, contents):
     # Separate the first line in the file from the remainder of the contents
     # while preserving the end of line sequence (CR+LF or just an LF) and
     # without having to split all lines in the file (there's no point).
-    parts = re.split(r'(\r?\n)', contents, 1)
-    hashbang = parts[0]
+    lines = contents.splitlines()
+    hashbang = lines[0]
     # Get the base name of the command in the hashbang and deal with hashbangs
     # like `#!/usr/bin/env python'.
-    modified_name = re.sub('^env ', '', os.path.basename(hashbang))
+    modified_name = re.sub(b'^env ', b'', os.path.basename(hashbang))
     # Only rewrite hashbangs that actually involve Python.
-    if re.match(r'^python(\d+(\.\d+)*)?$', modified_name):
-        logger.debug("Hashbang %r looks like a Python hashbang! We'll rewrite it!", hashbang)
-        parts[0] = '#!%s' % python
-        contents = ''.join(parts)
+    if re.match(b'^python(\\d+(\\.\\d+)*)?$', modified_name):
+        lines[0] = b'#!' + python.encode('ascii')
+        logger.debug("Hashbang %r looks like a Python hashbang! Rewriting it to %r!", hashbang, lines[0])
+        contents = b'\n'.join(lines)
     else:
         logger.debug("Warning: Failed to match hashbang: %r.", hashbang)
     return contents
